'use strict';

let mysql = require('mysql2');
let fs = require('fs');

class Install{
    constructor(dbcfg, sqlFiles, lockFile = 'install.lock'){
        this.dbcfg = dbcfg;
        this.sql = this.getsql(sqlFiles);
        this.lockFile = lockFile;
    }

    getsql(sqlFiles){
        if(typeof sqlFiles == 'string'){
            return fs.readFileSync(sqlFiles, 'utf8');
        }else if(Array.isArray(sqlFiles)){
            let sql = '';
            sqlFiles.forEach(sqlFile=>{
                sql += fs.readFileSync(sqlFile, 'utf8');
            });
            return sql;
        }else{
            throw new Error('sqlFiles should be string or array');
        }
    }

    execsql(dbcfg, sql, separator = ';'){
        let connection = mysql.createConnection(dbcfg);
        connection.connect();
        sql.split(separator).forEach(s=>{
            s.trim() && connection.query(s, err=>{if(err) throw err});
        });
        connection.end();
    }

    _makeLock(lockFile){
        fs.writeFileSync(lockFile, '');
    }

    _isLock(lockFile){
        try {
            return fs.statSync(lockFile).isFile();
        } catch(e) {
            return false;
        }
    }

    run(){
        let lockFile = this.lockFile;
        if(this._isLock(lockFile)){
            console.log('You have installed. Please delete '+lockFile+' to reinstall');
            return;
        }
        this.execsql(this.dbcfg, this.sql);
        this._makeLock(lockFile);
    }
}

module.exports = Install;

